/*
 *  XMail by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999,...,2002  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davidel@xmailserver.org>
 *
 */


#ifndef _APPDEFINES_H
#define _APPDEFINES_H




#define APP_PRODUCER            "GNU"
#define APP_NAME_STR            "XMail"
#define APP_VERSION_STR         "1.9"
#define APP_NAME_VERSION_STR    APP_NAME_STR " " APP_VERSION_STR
#define APP_NAME_VERSION_OS_STR APP_NAME_VERSION_STR " (" SYS_OS_PORT ")"
#define APP_URL                 "http://www.xmailserver.org"




#endif
